@@ -36,7 +36,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.11.2_05'; # TRIAL VERSION
+our $VERSION = 'v0.11.2_06'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -50,7 +50,8 @@ use Data::Section { installer => method_installer }, -setup;
 
 #   These modules are used by hooks. Require all the modules explicitly now to avoid unexpected
 #   failures in the middle of build or release.
-use File::chdir         ();
+use App::Prove          ();
+use File::pushd         ();
 use IPC::Run3           ();
 use IPC::System::Simple ();
 use Path::Tiny 0.070    ();
@@ -353,9 +354,6 @@ sub configure {
     our $Self = $self;                  ## no critic ( ProhibitPackageVars )
     my $name = $self->name;
 
-    require Dist::Zilla::Plugin::Manifest::Write;
-        # Make sure the plugin is loaded before checking its version.
-
     $self->add_plugins(
 
         [ 'Hook' => 'prologue' => {
@@ -446,9 +444,10 @@ sub configure {
         ) : (
         ),
 
-        [ 'Manifest::Write' => { # REQUIRED VERSION: v0.9.6
+        [ 'Manifest::Write' => { # REQUIRED VERSION: v0.9.7
             # `Manifest::Write` v0.9.0 strictly requires plugin names, not monikers.
             # `Manifest::Write` v0.9.6 provides `exclude_files` option.
+            # `Manifest::Write` v0.9.7 provides `manifest_skip` option and feature.
             'source_provider' => [
                 "$name/Manifest::Read",
                 $self->copying ne '' ? "$name/COPYING" : (),
@@ -461,7 +460,7 @@ sub configure {
                 "$name/MetaYAML",
             ],
             'exclude_files' => [
-                ":ExtraTestFiles",
+                ":ExtraTestFiles",          # REQUIRE: Dist::Zilla 5.038
             ],
         } ],
 
@@ -669,8 +668,6 @@ sub configure {
             } ],
         } ],
 
-        [ 'CheckPrereqsIndexed'   ],    # Make sure all prereqs are published in CPAN.
-
         [ 'MetaProvides::Package' ],
 
         [ 'MetaResources::Template' => {
@@ -723,8 +720,28 @@ sub configure {
         ) : (
         ),
 
-        #~ [ 'RunExtraTests' ],         # Does not work for me, see <https://github.com/dagolden/Dist-Zilla-Plugin-CheckExtraTests/issues/26>.
-        [ 'CheckExtraTests' ],          # So use CheckExtraTest meanwhile.
+        #   I want to run xtest before release. Neither RunExtraTests nor CheckExtraTests work for
+        #   me. The first one executes extra test when user runs `dzil test`. I do not want it,
+        #   because it slows down regular testing. The second one unpacks tarball, builds it, and
+        #   run extra tests… But tarball does not include extra tests.
+
+        [ 'Hook::BeforeRelease' => 'xtest' => {
+            'hook' => [ q{
+                use File::pushd;
+                my $wd = pushd( $zilla->ensure_built );
+                $zilla->_ensure_blib();
+                use App::Prove;
+                local $ENV{ AUTHOR_TESTING  } = 1;
+                local $ENV{ RELEASE_TESTING } = 1;
+                my $prove = App::Prove->new({
+                    blib    => 1,
+                    recurse => 1,
+                    argv    => [ 'xt' ],
+                });
+                $prove->run() or $self->log_error( "xtest failed" );
+                $self->abort_if_errors();
+            } ],
+        } ],
 
         [ 'TestRelease'     ],          # Unpack tarball and run tests.
 
@@ -752,14 +769,16 @@ sub configure {
             } ],
         } ],
 
+        [ 'CheckPrereqsIndexed'   ],    # Make sure all prereqs are published in CPAN.
+
         [ 'CheckChangesHasContent' ],
 
         $self->spellchecker ? (
             [ 'Hook::BeforeRelease' => 'spellcheck changes' => {
                 'hook' => [ q{
                     $self->log( 'spellchecking Changes' );
-                    use File::chdir;
-                    local $CWD = $zilla->built_in . '';
+                    use File::pushd;
+                    my $wd = pushd( $zilla->built_in );
                     #
                     #   Run spellchecker, collect list of unknown words.
                     #
@@ -876,9 +895,9 @@ sub configure {
         [ 'Hook::AfterRelease' => 'install' => {
             'hook' => [ q{
                 use autodie ':all';
-                use File::chdir;
+                use File::pushd;
                 $self->log( [ 'installing %s-%s', $dist->name, $dist->version ] );
-                local $CWD = $zilla->built_in;
+                my $wd = pushd( $zilla->built_in );
                 system( 'cpanm', '--notest', '.' );
                     # ^ We run the tests on unpacked tarball before release, no need in running
                     #   tests one more time.
@@ -961,7 +980,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.11.2_05, released on 2016-12-08 00:45 UTC.
+Version v0.11.2_06, released on 2016-12-15 22:13 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
